@@ -382,6 +382,20 @@ class CAM(object):
         """
         os.system("vim {0}".format(CONFIG_FILE))
 
+    def web(self, host = "127.0.0.1", port = 3257, rebuild = False):
+        """
+        Open a web panel.
+        Run `cam web --rebuild True` to rebuild the page.
+        """
+        log_info("Nodejs is required to run the web page.")
+        log_info("It is strongly suggested to run only on your local machine. NEVER run this on a public server!")
+        root = os.path.dirname(os.path.abspath(__file__))
+        if not os.path.exists(f"{root}/web/node_modules") or rebuild:
+            os.system(f"cd {root}/web && npm install")
+            os.system(f"cd {root}/web && npm run build")
+        os.system(f"cd {root}/web && HOST={host} PORT={port}  npm run start")
+
+
 def main():
     Cam = CAM()
     fire.Fire(Cam)
